<?php

namespace App\Http\Controllers\Admin;

use App\Categories;
use App\Http\Controllers\Controller;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;

class CategoriesController extends Controller
{
    public function index(Request $request)
    {
        $categories = Categories::all();
        if ($request->ajax()) {
            return Datatables::of($categories)->addIndexColumn()
                ->addColumn('created_at', function ($row) {
                    return Carbon::parse($row->created_at)->format('m/d/y h:i:s');
                })
                ->addColumn('action', function ($row) {
                    $id = $row->id;
                    $id = base64_encode($id);
                    $btn = '<button type="button" class="btn bg-grey"  onclick="editDomain(' . "'$id'" . ')" id=' . "$id" . ' id=' . "$id" . '><i class="uil uil-pen"></i> Edit Category</button>';
                    return $btn;
                })
                ->rawColumns(['action'])
                ->addColumn('status', function ($row) {
                    if ($row->status == '1') {
                        return 'Enabled';
                    } else {
                        return 'Disabled';
                    }

                })
                ->addColumn('name', function ($row) {

                    return $row->name;
                })
                ->addColumn('total_used', function ($row) {

                    return $row->used;
                })
                ->make(true);
        }
        return view('admin.categories.list_categories', compact('categories'));
    }

    public function reports()
    {
        return view('admin.categories.reports');
    }

    public function store(Request $request)
    {
        $this->validate($request, [

            'name' => 'required|unique:categories|max:20',

        ]);

        $categories = new Categories();
        $categories->name = $request->name;
        $categories->status = '1';
        $categories->save();
        return redirect()->back()->withMessage("Add Successfully");

    }

    public function edit(Request $request)
    {
        $category = Categories::find(base64_decode($request->id));
        return view('admin.categories.edit_categories', compact('category'));
    }

    public function update(Request $request)
    {
        $this->validate($request, [

            'name' => 'required|max:20|unique:categories,name,' . $request->id,

        ]);

        $categories = Categories::find($request->id);
        $categories->name = $request->name;
        $categories->status = $request->status;
        $categories->save();
        return redirect()->back()->withMessage("Update Successfully");

    }
}
