<?php

namespace App\Http\Controllers\Admin;

use App\Advertisement;
use App\Categories;
use App\Domains;
use App\DomainUsers;
use App\Http\Controllers\Controller;
use App\MetaDescription;
use App\Orders;
use App\OutSourceSold;
use App\Payments;
use App\Plans;
use App\Seo;
use App\SEOWEB;
use App\Theme;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;
use File;
use GuzzleHttp\Exception\GuzzleException;
use cPanelApi;
use GuzzleHttp\Client;
use phpDocumentor\Reflection\DocBlock\Tags\See;
use Stripe\Order;
use Yajra\DataTables\Facades\DataTables;

class DomainsController extends Controller
{
    public function store(Request $request)
    {

        if ($request->has('featured')) {
            $this->validate($request, [

                'domain_name' => 'required|regex:/^(?!:\/\/)(?=.{1,255}$)((.{1,63}\.){1,127}(?![0-9]*$)[a-z0-9-]+\.?)$/i|unique:domains',
                'price' => 'required|numeric',
//                'days' => 'required|numeric',
                'minimum_offer' => 'required|numeric',
                'logo' => 'nullable|dimensions:width=150,height=70',
                'categories' => 'required'
            ]);
        } else {
            $this->validate($request, [

                'domain_name' => 'required|regex:/^(?!:\/\/)(?=.{1,255}$)((.{1,63}\.){1,127}(?![0-9]*$)[a-z0-9-]+\.?)$/i|unique:domains',
                'price' => 'required|numeric',
                'minimum_offer' => 'required|numeric',
                'logo' => 'nullable|dimensions:width=150,height=70',
                'categories' => 'required'
            ]);
        }

        $domain = new Domains();
        $replace = str_replace('www.','',$request->domain_name);
        $explod = explode('.',$replace);
        $domain->domain_name = $replace;
        $domain->name = $explod[0];
        $domain->type = $explod[1];
        $domain->price = $request->price;
        $domain->minimum_offer = $request->minimum_offer;
        if ($request->has('featured')) {
            $newDateTime = Carbon::now()->addYears($request->days);
            $domain->featured = "1";
            $domain->days = $newDateTime->toDateString();
        } else {
            $domain->featured = "0";
        }

        if(!empty($request->logo))
        {
            $extension = $request->logo->getClientOriginalExtension();
            $size = $request->logo->getSize();
            $getInKb = $size / 1000;
            $getInMb = $getInKb / 1000;

            if ($getInMb <= 1000) {
                if ($extension == "jpeg" || $extension == "jpg" || $extension == "png") {

                    $file = $request->logo;
                    $imageName = Str::random(32);
                    $domain->logo = $imageName . "." . $extension;
                    $file->move('admin/assets/domain_logo', $imageName . "." . $extension);
                } else {
                    return back()->withInput()->withErrors(['You can upload only jpg , png or jpeg']);
                }
            }
            else{
                return back()->withInput()->withErrors(['Upload maximum 1Mb Size']);
            }
        }
        $domain->categories = json_encode($request->categories);
        $domain->save();

        foreach ($request->categories as $category) {
            $incCount = Categories::find($category);
            $incCount->used = $incCount->used+1;
            $incCount->save();
        }
        try {
            $client = new Client(); //GuzzleHttp\Client
            $domain = Domains::find($domain->id);
            $getStatus = $client->request('GET', "https://www.whoisxmlapi.com/whoisserver/WhoisService?apiKey=at_h0xMLQJOy9YEWrLGb2HZlHr4fumlL&domainName=" . $domain->domain_name . "&outputFormat=JSON", [
            ]);
            $getResult = json_decode($getStatus->getBody(), true);

            if (isset($getResult['ErrorMessage']['msg'])) {
                return redirect()->back()->withMessage($getResult['ErrorMessage']['msg']);

            } else {

                $domain->reg_date = isset($getResult['WhoisRecord']['registryData']['createdDate']) ? $getResult['WhoisRecord']['registryData']['createdDate']:"";
                $domain->updated_date = isset($getResult['WhoisRecord']['registryData']['updatedDate'])?$getResult['WhoisRecord']['registryData']['updatedDate']:"";
                $domain->expire_date = isset($getResult['WhoisRecord']['registryData']['expiresDate'])?$getResult['WhoisRecord']['registryData']['expiresDate']:"";
                $domain->name_server = isset($getResult['WhoisRecord']['registryData']['nameServers']['hostNames'])?json_encode($getResult['WhoisRecord']['registryData']['nameServers']['hostNames']):"";
                $domain->status = isset($getResult['WhoisRecord']['registryData']['status'])?$getResult['WhoisRecord']['registryData']['status']:"";
                $domain->registrar = isset($getResult['WhoisRecord']['registrarName'])?$getResult['WhoisRecord']['registrarName']:"";
                $domain->save();
            }
        } catch (GuzzleException $e) {
            return redirect()->back()->withErrors("Something went wrong , please try later");
        }
        return redirect()->back()->withMessage("Add Successfully");


    }

    public function edit($id)
    {
        $domains = Domains::find(base64_decode($id));
        $plans = Plans::where('domain_id', base64_decode($id))->get();
        $advertisements = Advertisement::where('domain_id', base64_decode($id))->get();
        $metaDescriptions = MetaDescription::where('domain_id', base64_decode($id))->get();
        $themes = Theme::where('domain_id', base64_decode($id))->get();
        $seo = SEOWEB::first();
        $category = Categories::where('status','1')->get();
        $saveCat=json_decode($domains->categories, true);
        return view('admin/domains/edit_domain', compact('seo','saveCat','domains', 'plans', 'advertisements', 'metaDescriptions', 'themes','category'));
    }

    public function update(Request $request)
    {

        if ($request->has('featured')) {
            $this->validate($request, [

                'domain_name' => 'required|regex:/^(?!:\/\/)(?=.{1,255}$)((.{1,63}\.){1,127}(?![0-9]*$)[a-z0-9-]+\.?)$/i|unique:domains,domain_name,'.base64_decode($request->domain_id),
                'price' => 'required|numeric',
                'minimum_offer' => 'required|numeric',
                'logo' => 'nullable|dimensions:width=150,height=70',
                'categories' => 'required'

                //'year' => 'required|numeric',
            ]);
        } else {
            $this->validate($request, [

                'domain_name' => 'required|regex:/^(?!:\/\/)(?=.{1,255}$)((.{1,63}\.){1,127}(?![0-9]*$)[a-z0-9-]+\.?)$/i|unique:domains,domain_name,'.base64_decode($request->domain_id),
                'price' => 'required|numeric',
                'minimum_offer' => 'required|numeric',
                'logo' => 'nullable|dimensions:width=150,height=70',
                'categories' => 'required'
            ]);
        }
        if ($request->has('plan_enable')) {
            $this->validate($request, [

                /*  'months_3_price' => 'required|numeric',
                  'months_3_apr' => 'required|numeric',
                  'months_3_investment' => 'required|numeric',
                  'months_6_price' => 'required|numeric',
                  'months_6_apr' => 'required|numeric',
                  'months_6_investment' => 'required|numeric',
                  'months_9_price' => 'required|numeric',
                  'months_9_apr' => 'required|numeric',
                  'months_9_investment' => 'required|numeric',
                  'months_12_price' => 'required|numeric',
                  'months_12_apr' => 'required|numeric',
                  'months_12_investment' => 'required|numeric',*/
                'months' => 'required|numeric',
                'months_apr' => 'required|numeric',
                'months_price' => 'required|numeric',
                'months_interest' => 'required|numeric',
            ]);
        } else {
            $this->validate($request, [

                /* 'months_3_price' => 'nullable|numeric',
                 'months_3_apr' => 'nullable|numeric',
                 'months_3_investment' => 'nullable|numeric',
                 'months_6_price' => 'nullable|numeric',
                 'months_6_apr' => 'nullable|numeric',
                 'months_6_investment' => 'nullable|numeric',
                 'months_9_price' => 'nullable|numeric',
                 'months_9_apr' => 'nullable|numeric',
                 'months_9_investment' => 'nullable|numeric',
                 'months_12_price' => 'nullable|numeric',
                 'months_12_apr' => 'nullable|numeric',
                 'months_12_investment' => 'nullable|numeric',*/
                'months' => 'nullable|numeric',
                'months_apr' => 'nullable|numeric',
                'months_price' => 'nullable|numeric',
                'months_interest' => 'nullable|numeric',

            ]);
        }

        $this->validate($request, [

            'meta_description' => 'nullable|string|max:2000',
            'og_description' => 'nullable|string|max:2000',
        ]);

        $domain = Domains::find(base64_decode($request->domain_id));
        $replace = str_replace('www.','',$request->domain_name);
        $explod = explode('.',$replace);
        $domain->domain_name = $replace;
        $domain->name = $explod[0];
        $domain->type = $explod[1];
        $domain->price = $request->price;
        if ($request->has('featured')) {
            //$newDateTime = Carbon::now()->addYears($request->year);
            $domain->featured = "1";
            //$domain->days = $newDateTime->toDateString();
        } else {
            $domain->featured = "0";
        }


        if (!empty($request->logo)) {
            $extension = $request->logo->getClientOriginalExtension();
            $size = $request->logo->getSize();
            $getInKb = $size / 1000;
            $getInMb = $getInKb / 1000;

            if ($getInMb <= 1000) {
                if ($extension == "jpeg" || $extension == "jpg" || $extension == "png") {
                    $large_image = public_path('admin/assets/domain_logo'.$domain->logo);
                    File::delete($large_image);
                    $file = $request->logo;
                    $imageName = Str::random(32);
                    $domain->logo = $imageName . "." . $extension;
                    $file->move('admin/assets/domain_logo', $imageName . "." . $extension);
                } else {
                    return back()->withInput()->withErrors(['You can upload only jpg , png or jpeg']);
                }
            }
            else{
                return back()->withInput()->withErrors(['Image size must be mazimum 1MB']);
            }
        }
        if(!empty(json_decode($domain->categories,true)))
        {
            $result = array_diff( $request->categories,json_decode($domain->categories,true));
            foreach ($result as $addCatCount)
            {
                $countCat = Categories::find($addCatCount);
                $countCat->used = $countCat->used+1;
                $countCat->save();
            }

            $result1 = array_diff(json_decode($domain->categories,true), $request->categories);
            foreach ($result1 as $removeCatCount)
            {
                $countCat = Categories::find($removeCatCount);
                $countCat->used = $countCat->used-1;
                if($countCat->used<0)
                {
                    $countCat->used = '0';
                }
                $countCat->save();
            }

            $domain->categories = $request->categories;
        }
        else{
            foreach ($request->categories as $removeCatCount)
            {
                $countCat = Categories::find($removeCatCount);
                $countCat->used = $countCat->used+1;
                $countCat->save();
            }

        }

        $domain->categories = $request->categories;
        $domain->minimum_offer = $request->minimum_offer;
        $domain->save();


        ////////////////////////////////// plans ////////////////////////////////////////

        $checkPlan = Plans::where('domain_id', base64_decode($request->domain_id))->first();
        if (!empty($checkPlan->id)) {
            $plans = Plans::find($checkPlan->id);
            if($request->months =="3")
            {
                $plans->month_3_price = number_format((float)$request->months_price/3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = null;
                $plans->month_6_apr = null;
                $plans->month_6_interest = null;
                $plans->month_9_price = null;
                $plans->month_9_apr = null;
                $plans->month_9_interest = null;
                $plans->month_12_price = null;
                $plans->month_12_apr = null;
                $plans->month_12_interest = null;
                $plans->month_18_price = null;
                $plans->month_18_apr = null;
                $plans->month_18_interest = null;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_24_price = null;
                $plans->month_24_apr = null;
                $plans->month_24_interest = null;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="6")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price/6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = null;
                $plans->month_9_apr = null;
                $plans->month_9_interest = null;
                $plans->month_12_price = null;
                $plans->month_12_apr = null;
                $plans->month_12_interest = null;
                $plans->month_18_price = null;
                $plans->month_18_apr = null;
                $plans->month_18_interest = null;
                $plans->month_24_price = null;
                $plans->month_24_apr = null;
                $plans->month_24_interest = null;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="9")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price / 6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = number_format((float)$request->months_price/9, 2, '.', '');
                $plans->month_9_apr = $request->months_apr;
                $plans->month_9_interest = $request->months_interest;
                $plans->month_12_price = null;
                $plans->month_12_apr = null;
                $plans->month_12_interest = null;
                $plans->month_18_price = null;
                $plans->month_18_apr = null;
                $plans->month_18_interest = null;
                $plans->month_24_price = null;
                $plans->month_24_apr = null;
                $plans->month_24_interest = null;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="12")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price / 6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = number_format((float)$request->months_price / 9, 2, '.', '');
                $plans->month_9_apr = $request->months_apr;
                $plans->month_9_interest = $request->months_interest;
                $plans->month_12_price = number_format((float)$request->months_price/12, 2, '.', '');
                $plans->month_12_apr = $request->months_apr;
                $plans->month_12_interest = $request->months_interest;
                $plans->month_18_price = null;
                $plans->month_18_apr = null;
                $plans->month_18_interest = null;
                $plans->month_24_price = null;
                $plans->month_24_apr = null;
                $plans->month_24_interest = null;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="18")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price / 6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = number_format((float)$request->months_price / 9, 2, '.', '');
                $plans->month_9_apr = $request->months_apr;
                $plans->month_9_interest = $request->months_interest;
                $plans->month_12_price = number_format((float)$request->months_price / 12, 2, '.', '');
                $plans->month_12_apr = $request->months_apr;
                $plans->month_12_interest = $request->months_interest;
                $plans->month_18_price = number_format((float)$request->months_price/18, 2, '.', '');
                $plans->month_18_apr = $request->months_apr;
                $plans->month_18_interest = $request->months_interest;
                $plans->month_24_price = null;
                $plans->month_24_apr = null;
                $plans->month_24_interest = null;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="24")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price / 6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = number_format((float)$request->months_price / 9, 2, '.', '');
                $plans->month_9_apr = $request->months_apr;
                $plans->month_9_interest = $request->months_interest;
                $plans->month_18_price = number_format((float)$request->months_price / 18, 2, '.', '');
                $plans->month_18_apr = $request->months_apr;
                $plans->month_18_interest = $request->months_interest;
                $plans->month_12_price = number_format((float)$request->months_price / 12, 2, '.', '');
                $plans->month_12_apr = $request->months_apr;
                $plans->month_12_interest = $request->months_interest;
                $plans->month_24_price = number_format((float)$request->months_price/24, 2, '.', '');
                $plans->month_24_apr = $request->months_apr;
                $plans->month_24_interest = $request->months_interest;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="36")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price / 6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = number_format((float)$request->months_price / 9, 2, '.', '');
                $plans->month_9_apr = $request->months_apr;
                $plans->month_9_interest = $request->months_interest;
                $plans->month_12_price = number_format((float)$request->months_price / 12, 2, '.', '');
                $plans->month_12_apr = $request->months_apr;
                $plans->month_12_interest = $request->months_interest;
                $plans->month_18_price = number_format((float)$request->months_price / 18, 2, '.', '');
                $plans->month_18_apr = $request->months_apr;
                $plans->month_18_interest = $request->months_interest;
                $plans->month_24_price = number_format((float)$request->months_price / 24, 2, '.', '');
                $plans->month_24_apr = $request->months_apr;
                $plans->month_24_interest = $request->months_interest;
                $plans->month_36_price = number_format((float)$request->months_price/36, 2, '.', '');
                $plans->month_36_apr = $request->months_apr;
                $plans->month_36_interest = $request->months_interest;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="48")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price / 6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = number_format((float)$request->months_price / 9, 2, '.', '');
                $plans->month_9_apr = $request->months_apr;
                $plans->month_9_interest = $request->months_interest;
                $plans->month_12_price = number_format((float)$request->months_price / 12, 2, '.', '');
                $plans->month_12_apr = $request->months_apr;
                $plans->month_12_interest = $request->months_interest;
                $plans->month_18_price = number_format((float)$request->months_price / 18, 2, '.', '');
                $plans->month_18_apr = $request->months_apr;
                $plans->month_18_interest = $request->months_interest;
                $plans->month_24_price = number_format((float)$request->months_price / 24, 2, '.', '');
                $plans->month_24_apr = $request->months_apr;
                $plans->month_24_interest = $request->months_interest;
                $plans->month_36_price = number_format((float)number_format((float)$request->months_price / 36, 2, '.', ''), 2, '.', '');
                $plans->month_36_apr = $request->months_apr;
                $plans->month_36_interest = $request->months_interest;
                $plans->month_48_price = number_format((float)$request->months_price/48, 2, '.', '');
                $plans->month_48_apr = $request->months_apr;
                $plans->month_48_interest = $request->months_interest;
            }
            /*$plans->month_3_price = $request->months_3_price;
            $plans->month_3_apr = $request->months_3_apr;
            $plans->month_3_interest = $request->months_3_investment;
            $plans->month_6_price = $request->months_6_price;
            $plans->month_6_apr = $request->months_6_apr;
            $plans->month_6_interest = $request->months_6_investment;
            $plans->month_9_price = $request->months_9_price;
            $plans->month_9_apr = $request->months_9_apr;
            $plans->month_9_interest = $request->months_9_investment;
            $plans->month_12_price = $request->months_12_price;
            $plans->month_12_apr = $request->months_12_apr;
            $plans->month_12_interest = $request->months_12_investment;*/
            $plans->domain_id = base64_decode($request->domain_id);
            $plans->selected_month = $request->months;
            $plans->price =$request->months_price;
            $plans->save();
        } else {
            $plans = new Plans();
            if($request->months =="3")
            {
                $plans->month_3_price = number_format((float)$request->months_price/3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = null;
                $plans->month_6_apr = null;
                $plans->month_6_interest = null;
                $plans->month_9_price = null;
                $plans->month_9_apr = null;
                $plans->month_9_interest = null;
                $plans->month_12_price = null;
                $plans->month_12_apr = null;
                $plans->month_12_interest = null;
                $plans->month_18_price = null;
                $plans->month_18_apr = null;
                $plans->month_18_interest = null;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_24_price = null;
                $plans->month_24_apr = null;
                $plans->month_24_interest = null;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="6")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price/6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = null;
                $plans->month_9_apr = null;
                $plans->month_9_interest = null;
                $plans->month_12_price = null;
                $plans->month_12_apr = null;
                $plans->month_12_interest = null;
                $plans->month_18_price = null;
                $plans->month_18_apr = null;
                $plans->month_18_interest = null;
                $plans->month_24_price = null;
                $plans->month_24_apr = null;
                $plans->month_24_interest = null;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="9")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price / 6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = number_format((float)$request->months_price/9, 2, '.', '');
                $plans->month_9_apr = $request->months_apr;
                $plans->month_9_interest = $request->months_interest;
                $plans->month_12_price = null;
                $plans->month_12_apr = null;
                $plans->month_12_interest = null;
                $plans->month_18_price = null;
                $plans->month_18_apr = null;
                $plans->month_18_interest = null;
                $plans->month_24_price = null;
                $plans->month_24_apr = null;
                $plans->month_24_interest = null;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="12")
            {
                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price / 6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = number_format((float)$request->months_price / 9, 2, '.', '');
                $plans->month_9_apr = $request->months_apr;
                $plans->month_9_interest = $request->months_interest;
                $plans->month_12_price = number_format((float)$request->months_price/12, 2, '.', '');
                $plans->month_12_apr = $request->months_apr;
                $plans->month_12_interest = $request->months_interest;
                $plans->month_18_price = null;
                $plans->month_18_apr = null;
                $plans->month_18_interest = null;
                $plans->month_24_price = null;
                $plans->month_24_apr = null;
                $plans->month_24_interest = null;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="18")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price / 6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = number_format((float)$request->months_price / 9, 2, '.', '');
                $plans->month_9_apr = $request->months_apr;
                $plans->month_9_interest = $request->months_interest;
                $plans->month_12_price = number_format((float)$request->months_price / 12, 2, '.', '');
                $plans->month_12_apr = $request->months_apr;
                $plans->month_12_interest = $request->months_interest;
                $plans->month_18_price = number_format((float)$request->months_price/18, 2, '.', '');
                $plans->month_18_apr = $request->months_apr;
                $plans->month_18_interest = $request->months_interest;
                $plans->month_24_price = null;
                $plans->month_24_apr = null;
                $plans->month_24_interest = null;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="24")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price / 6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = number_format((float)$request->months_price / 9, 2, '.', '');
                $plans->month_9_apr = $request->months_apr;
                $plans->month_9_interest = $request->months_interest;
                $plans->month_18_price = number_format((float)$request->months_price / 18, 2, '.', '');
                $plans->month_18_apr = $request->months_apr;
                $plans->month_18_interest = $request->months_interest;
                $plans->month_12_price = number_format((float)$request->months_price / 12, 2, '.', '');
                $plans->month_12_apr = $request->months_apr;
                $plans->month_12_interest = $request->months_interest;
                $plans->month_24_price = number_format((float)$request->months_price/24, 2, '.', '');
                $plans->month_24_apr = $request->months_apr;
                $plans->month_24_interest = $request->months_interest;
                $plans->month_36_price = null;
                $plans->month_36_apr = null;
                $plans->month_36_interest = null;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="36")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price / 6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = number_format((float)$request->months_price / 9, 2, '.', '');
                $plans->month_9_apr = $request->months_apr;
                $plans->month_9_interest = $request->months_interest;
                $plans->month_12_price = number_format((float)$request->months_price / 12, 2, '.', '');
                $plans->month_12_apr = $request->months_apr;
                $plans->month_12_interest = $request->months_interest;
                $plans->month_18_price = number_format((float)$request->months_price / 18, 2, '.', '');
                $plans->month_18_apr = $request->months_apr;
                $plans->month_18_interest = $request->months_interest;
                $plans->month_24_price = number_format((float)$request->months_price / 24, 2, '.', '');
                $plans->month_24_apr = $request->months_apr;
                $plans->month_24_interest = $request->months_interest;
                $plans->month_36_price = number_format((float)$request->months_price/36, 2, '.', '');
                $plans->month_36_apr = $request->months_apr;
                $plans->month_36_interest = $request->months_interest;
                $plans->month_48_price = null;
                $plans->month_48_apr = null;
                $plans->month_48_interest = null;
            }
            else if($request->months =="48")
            {

                $plans->month_3_price = number_format((float)$request->months_price / 3, 2, '.', '');
                $plans->month_3_apr = $request->months_apr;
                $plans->month_3_interest = $request->months_interest;
                $plans->month_6_price = number_format((float)$request->months_price / 6, 2, '.', '');
                $plans->month_6_apr = $request->months_apr;
                $plans->month_6_interest = $request->months_interest;
                $plans->month_9_price = number_format((float)$request->months_price / 9, 2, '.', '');
                $plans->month_9_apr = $request->months_apr;
                $plans->month_9_interest = $request->months_interest;
                $plans->month_12_price = number_format((float)$request->months_price / 12, 2, '.', '');
                $plans->month_12_apr = $request->months_apr;
                $plans->month_12_interest = $request->months_interest;
                $plans->month_18_price = number_format((float)$request->months_price / 18, 2, '.', '');
                $plans->month_18_apr = $request->months_apr;
                $plans->month_18_interest = $request->months_interest;
                $plans->month_24_price = number_format((float)$request->months_price / 24, 2, '.', '');
                $plans->month_24_apr = $request->months_apr;
                $plans->month_24_interest = $request->months_interest;
                $plans->month_36_price = number_format((float)number_format((float)$request->months_price / 36, 2, '.', ''), 2, '.', '');
                $plans->month_36_apr = $request->months_apr;
                $plans->month_36_interest = $request->months_interest;
                $plans->month_48_price = number_format((float)$request->months_price/48, 2, '.', '');
                $plans->month_48_apr = $request->months_apr;
                $plans->month_48_interest = $request->months_interest;
            }
            $plans->domain_id = base64_decode($request->domain_id);
            $plans->selected_month = $request->months;
            $plans->price =$request->months_price;
            $plans->save();
        }

        /////////////////////////////////////// Advertisement /////////////////////////////////////

        $checkAdv = Advertisement::where('domain_id', base64_decode($request->domain_id))->first();
        if (!empty($checkAdv->id)) {
            $adv = Advertisement::find($checkAdv->id);
            $adv->ad_1 = $request->ad_1;
            $adv->ad_2 = $request->ad_2;
            $adv->ad_3 = $request->ad_3;
            $adv->ad_4 = $request->ad_4;
            $adv->save();
        } else {
            $adv = new Advertisement();
            $adv->ad_1 = $request->ad_1;
            $adv->ad_2 = $request->ad_2;
            $adv->ad_3 = $request->ad_3;
            $adv->ad_4 = $request->ad_4;
            $adv->domain_id = base64_decode($request->domain_id);
            $adv->save();
        }

        ///////////////////////////////////// Meta Description /////////////////////////////////

        $checkMeta = MetaDescription::where('domain_id', base64_decode($request->domain_id))->first();
        if (!empty($checkMeta->id)) {
            $meta = MetaDescription::find($checkMeta->id);
            $meta->meta_description = $request->meta_description;
            $meta->og_description = $request->og_description;
            $meta->meta_keywords = $request->meta_keywords;
            $meta->og_title = $request->og_title;
            $meta->save();
        } else {
            $meta = new MetaDescription();
            $meta->meta_description = $request->meta_description;
            $meta->og_description = $request->og_description;
            $meta->meta_keywords = $request->meta_keywords;
            $meta->og_title = $request->og_title;
            $meta->domain_id = base64_decode($request->domain_id);
            $meta->save();
        }

        //////////////////////////  Theme ///////////////////////////////////////


        $checkTheme = Theme::where('domain_id', base64_decode($request->domain_id))->first();
        if (!empty($checkTheme->id)) {
            $theme = Theme::find($checkTheme->id);
            if ($request->has('start_plan_section')) {
                $theme->start_plan_section = '1';
            } else {
                $theme->start_plan_section = '0';
            }
            if ($request->has('buy_domain_section')) {
                $theme->buy_domain_section = '1';
            } else {
                $theme->buy_domain_section = '0';
            }
            if ($request->has('partner_section')) {
                $theme->partner_section = '1';
            } else {
                $theme->partner_section = '0';
            }
            if ($request->has('benefits_section')) {
                $theme->benefits_section = '1';
            } else {
                $theme->benefits_section = '0';
            }
            if ($request->has('creative_section')) {
                $theme->creative_section = '1';
            } else {
                $theme->creative_section = '0';
            }
            if ($request->has('video_section')) {
                $theme->video_section = '1';
            } else {
                $theme->video_section = '0';
            }
            if ($request->has('opportunity_section')) {
                $theme->opportunity_section = '1';
            } else {
                $theme->opportunity_section = '0';
            }
            if ($request->has('advantage_section')) {
                $theme->advantage_section = '1';
            } else {
                $theme->advantage_section = '0';
            }
            if ($request->has('footer_buy_domain_section')) {
                $theme->footer_buy_domain_section = '1';
            } else {
                $theme->footer_buy_domain_section = '0';
            }
            if ($request->has('stripe')) {
                $theme->stripe = '1';
            } else {
                $theme->stripe = '0';
            }
            if ($request->has('paypal')) {
                $theme->paypal = '1';
            } else {
                $theme->paypal = '0';
            }
            if ($request->has('escrow')) {
                $theme->escrow = '1';
            } else {
                $theme->escrow = '0';
            }
            $theme->video_id = $request->video_id;
            $theme->save();
        } else {
            $theme = new Theme();
            if ($request->has('start_plan_section')) {
                $theme->start_plan_section = '1';
            } else {
                $theme->start_plan_section = '0';
            }
            if ($request->has('buy_domain_section')) {
                $theme->buy_domain_section = '1';
            } else {
                $theme->buy_domain_section = '0';
            }
            if ($request->has('partner_section')) {
                $theme->partner_section = '1';
            } else {
                $theme->partner_section = '0';
            }
            if ($request->has('benefits_section')) {
                $theme->benefits_section = '1';
            } else {
                $theme->benefits_section = '0';
            }
            if ($request->has('creative_section')) {
                $theme->creative_section = '1';
            } else {
                $theme->creative_section = '0';
            }
            if ($request->has('video_section')) {
                $theme->video_section = '1';
            } else {
                $theme->video_section = '0';
            }
            if ($request->has('opportunity_section')) {
                $theme->opportunity_section = '1';
            } else {
                $theme->opportunity_section = '0';
            }
            if ($request->has('advantage_section')) {
                $theme->advantage_section = '1';
            } else {
                $theme->advantage_section = '0';
            }
            if ($request->has('footer_buy_domain_section')) {
                $theme->footer_buy_domain_section = '1';
            } else {
                $theme->footer_buy_domain_section = '0';
            }
            if ($request->has('stripe')) {
                $theme->stripe = '1';
            } else {
                $theme->stripe = '0';
            }
            if ($request->has('paypal')) {
                $theme->paypal = '1';
            } else {
                $theme->paypal = '0';
            }
            if ($request->has('escrow')) {
                $theme->escrow = '1';
            } else {
                $theme->escrow = '0';
            }
            $theme->video_id = $request->video_id;
            $theme->domain_id = base64_decode($request->domain_id);
            $theme->save();
        }

        return redirect()->back()->withMessage("Add Successfully");
    }

    public function seo()
    {
        return view('admin/seo/index');
    }

    public function getDomainTab($id)
    {
        $domain = Domains::find(base64_decode($id));

        return view('admin.domains.domain_tab', compact('domain'));
    }
    public function domainRefresh(Request $request)
    {
        try {
            $client = new Client(); //GuzzleHttp\Client
            $domain = Domains::find(base64_decode($request->id));
            $getStatus = $client->request('GET', "https://www.whoisxmlapi.com/whoisserver/WhoisService?apiKey=at_h0xMLQJOy9YEWrLGb2HZlHr4fumlL&domainName=" . $domain->domain_name . "&outputFormat=JSON", [
            ]);
            $getResult = json_decode($getStatus->getBody(), true);

            if (isset($getResult['ErrorMessage']['msg'])) {
                return redirect()->back()->withMessage($getResult['ErrorMessage']['msg']);

            } else {

                $domain->reg_date = isset($getResult['WhoisRecord']['registryData']['createdDate']) ? $getResult['WhoisRecord']['registryData']['createdDate']:"";
                $domain->updated_date = isset($getResult['WhoisRecord']['registryData']['updatedDate'])?$getResult['WhoisRecord']['registryData']['updatedDate']:"";
                $domain->expire_date = isset($getResult['WhoisRecord']['registryData']['expiresDate'])?$getResult['WhoisRecord']['registryData']['expiresDate']:"";
                $domain->name_server = isset($getResult['WhoisRecord']['registryData']['nameServers']['hostNames'])?json_encode($getResult['WhoisRecord']['registryData']['nameServers']['hostNames']):"";
                $domain->status = isset($getResult['WhoisRecord']['registryData']['status'])?$getResult['WhoisRecord']['registryData']['status']:"";
                $domain->registrar = isset($getResult['WhoisRecord']['registrarName'])?$getResult['WhoisRecord']['registrarName']:"";
                $domain->save();

                return redirect()->back()->withMessage("Refresh Data Successfully");


            }
        } catch (GuzzleException $e) {
            return redirect()->back()->withErrors("Something went wrong , please try later");
        }
    }

    public function domainSold(Request $request)
    {
     /*   $domains = Payments::all();
        if ($request->ajax()) {
            return Datatables::of($domains)->addIndexColumn()
                ->addColumn('created_at', function ($row) {
                    return Carbon::parse($row->created_at)->format('m-d-y h:i:s');
                })
                ->addColumn('domain_name', function ($row) {

                    return $row->getDomain->domain_name;
                })
                ->addColumn('name', function ($row) {

                    return $row->getTotal->getUsers->first_name." " .$row->getTotal->getUsers->last_name;
                })
                ->addColumn('email', function ($row) {

                    return $row->getTotal->getUsers->email;
                })
                ->addColumn('pay', function ($row) {

                    return $row->getTotal->total_price;
                })
                ->addColumn('address', function ($row) {

                    return $row->getTotal->address_1;
                })->make(true);
        }*/

        $domains = OutSourceSold::all();
        if ($request->ajax()) {
            return Datatables::of($domains)->addIndexColumn()
                ->addColumn('created_at', function ($row) {
                    return Carbon::parse($row->date)->format('m-d-y');
                })
                ->addColumn('domain_name', function ($row) {

                    return $row->name;
                })

                ->addColumn('price', function ($row) {

//                    return $row->price;
                    return '$ '.number_format($row->price);
                })
                ->addColumn('fee', function ($row) {

//                    return $row->fee;
                    return '$ '.number_format($row->fee);

                })
                ->addColumn('commission', function ($row) {

//                    return $row->commission;
                    return '$ '.number_format($row->commission);

                })
                ->addColumn('action', function( $row ){
                    $id = $row->id;
                    $id = base64_encode($id);
                    if($row->just_missed=='0') {
                        $btn ='<button type="button" class="btn bg-grey"  onclick="editDomain(' . "'$id'" . ')" id=' . "$id" . ' id=' . "$id" . '><i class="uil uil-pen"></i> Edit</button>'." ".
                            '<button type="button" class="btn btn-info btn-padding"  onclick="missiedDomain(' . "'$id'" . ')" id=' . "$id" . ' id=' . "$id" . '><i class="uil uil-plus"></i> Add (just sold)</button>'." ".
                            '<button type="button" class="btn btn-danger"  onclick="deleteDomain(' . "'$id'" . ')" id=' . "$id" . ' id=' . "$id" . '><i class="uil uil-trash"></i> Delete</button>';
                        return $btn;
                    }
                       $btn =
                           '<button type="button" class="btn bg-grey"  onclick="editDomain(' . "'$id'" . ')" id=' . "$id" . ' id=' . "$id" . '><i class="uil uil-pen"></i> Edit</button>'." ".
                           '<button type="button" class="btn btn-warning"  onclick="removeMissiedDomain(' . "'$id'" . ')" id=' . "$id" . ' id=' . "$id" . '><i class="glyphicon glyphicon-remove"></i> Remove ( just sold)</button>'." ".
                           '<button type="button" class="btn btn-danger"  onclick="deleteDomain(' . "'$id'" . ')" id=' . "$id" . ' id=' . "$id" . '><i class="uil uil-trash"></i> Delete</button>';
                    return $btn;;
                })
                ->addColumn('market_place', function ($row) {

                    return $row->market_place;
                })->make(true);
        }

        return view('admin.domains.sold_domain',compact('domains'));
    }

//    Inquiries tabs
    public function general_inquiries()
    {
        return view('admin.inquiries.general_inquiries');
    }
    public function general_inquiry_details()
    {
        return view('admin.inquiries.general_inquiry_details');
    }

    public function customer_inquiries()
    {
        return view('admin.inquiries.customer_inquiries');
    }
    public function customer_inquiry_details()
    {
        return view('admin.inquiries.customer_inquiry_details');
    }

//    Invoices tabs
    public function invoices()
    {
        return view('admin.invoices.invoice_list');
    }
    public function invoice_list_details()
    {
        return view('admin.invoices.invoice_list_details');
    }

    //customer tabs
    public function customer(Request $request)
    {
        $users = DomainUsers::all();
        if ($request->ajax()) {
            return Datatables::of($users)->addIndexColumn()
                ->addColumn('created_at', function ($row) {
                    return Carbon::parse($row->created_at)->format('m-d-y h:i:s');
                })
                ->addColumn('domain', function( $row ){
                    $id = $row->id;
                    $id = base64_encode($id);
                    $btn =  '<a class="text-primary" href="'.asset("admin/customer/customer_details/$id").'">View Detail</a>';
                    return $btn;
                })
                ->rawColumns(['domain'])
                ->addColumn('address', function ($row) {

                    $getAddress = $row->getAddress($row->user_id , $row->domain_id);
                    return $getAddress->first_name." " .$getAddress->last_name;
                })
                ->addColumn('email', function ($row) {

                    return $row->user->email;
                })
                ->addColumn('phone', function ($row) {
                    $getAddress = $row->getAddress($row->user_id , $row->domain_id);
                    return $getAddress->phone;
                })
                ->addColumn('pay', function ($row) {

                    return "";
                })->make(true);
        }
        return view('admin.customer.user',compact('users'));
    }
    public function customer_details()
    {
        return view('admin.customer.user_details');
    }
    public function incoming_payment()
    {
        return view('admin.payment_details.incoming_payment');
    }
    public function received()
    {
        return view('admin.payment_details.received');
    }
    public function onhold_transaction()
    {
        return view('admin.payment_details.onhold_transaction');
    }
    public function paid_transaction()
    {
        return view('admin.payment_details.paid_transaction');
    }

    public function markAsSold(Request $request)
    {
        $markAsSold = new OutSourceSold();
        $domain = Domains::find(base64_decode($request->id));
            $this->validate($request, [

                'fee' => 'nullable|numeric',
                'price' => 'required|numeric',
                'commission' => 'nullable|numeric',
                'market_place' => 'required|string|max:200',
                'date' => 'required|string',
                'note' => 'nullable|string|max:200',

            ]);
        $markAsSold->name =$domain->domain_name;
        $markAsSold->domain_id = base64_decode($request->id);
            $markAsSold->market_place = $request->market_place;
        $markAsSold->fee = $request->fee;
        $markAsSold->price = $request->price;
        $markAsSold->commission = $request->commission;
        $markAsSold->date = $request->date;
        $markAsSold->description = $request->note;
            $markAsSold->save();

            $domain->sold = '1';
            $domain->save();
            return back()->withMessage('Upload Successfully');

    }
    public function dropped()
    {
        return view('admin.domains.dropped');
    }
    public function under_review()
    {
        return view('admin.domains.under_review');
    }
    public function expiring(Request $request)
    {
        $domains = Domains::where('sold','!=','0')->where('is_expired','2')->get();
        if ($request->ajax()) {
            return Datatables::of($domains)->addIndexColumn()
                ->addColumn('created_at', function ($row) {

                        return Carbon::parse($row->created_at)->format('m-d-y');

                })
                ->addColumn('domain_name', function ($row) {

                    return $row->domain_name;
                })

                ->addColumn('price', function ($row) {

                    return $row->price;
                })
                ->addColumn('expiry', function ($row) {

                    return $row->expire_date;
                })
                ->addColumn('update', function ($row) {

                    return $row->updated_date;
                })->make(true);
        }
        return view('admin.domains.expiring');
    }
    public function expired(Request $request)
    {
        $domains = Domains::where('sold','!=','0')->where('is_expired','1')->get();
        if ($request->ajax()) {
            return Datatables::of($domains)->addIndexColumn()
                ->addColumn('created_at', function ($row) {

                    return Carbon::parse($row->created_at)->format('m-d-y');

                })
                ->addColumn('domain_name', function ($row) {

                    return $row->domain_name;
                })

                ->addColumn('price', function ($row) {

                    return $row->price;
                })
                ->addColumn('expiry', function ($row) {

                    return $row->expire_date;
                })
                ->addColumn('update', function ($row) {

                    return $row->updated_date;
                })->make(true);
        }
        return view('admin.domains.expired');
    }
    public function just_missed_them()
    {
        return view('admin.domains.just_missed_them');
    }
    public function google_analytics()
    {
        return view('admin.google_analytics.google_analytics');
    }

}
