<?php

namespace App\Http\Controllers\Admin;

use App\Domains;
use App\Http\Controllers\Controller;
use App\OutSourceSold;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;

class OutSourceSoldDomainController extends Controller
{
    public function index(Request $request)
    {
        $domains = OutSourceSold::where('just_missed','1')->get();
        if ($request->ajax()) {
            return Datatables::of($domains)->addIndexColumn()
                ->addColumn('created_at', function ($row) {
                    if(!empty($row->date))
                    {
                        return Carbon::parse($row->date)->format('m/d/y');
                    }
                    else
                    {
                        return Carbon::parse($row->created_at)->format('m/d/y');
                    }

                })
                ->addColumn('domain_name', function ($row) {

                    return $row->name;
                })

                ->addColumn('price', function ($row) {

                    return $row->price;
                })
                ->addColumn('fee', function ($row) {

                    return $row->fee;
                })
                ->addColumn('commission', function ($row) {

                    return $row->commission;
                })
                ->addColumn('action', function( $row ){
                    $id = $row->id;
                    $id = base64_encode($id);
                    $btn = '<button type="button" class="btn btn-warning"  onclick="removeMissiedDomain(' . "'$id'" . ')" id=' . "$id" . ' id=' . "$id" . '><i class="glyphicon glyphicon-remove"</i> Remove ( Just Sold)</button>';
                    return $btn;;
                })
                ->addColumn('market_place', function ($row) {

                    return $row->market_place;
                })->make(true);
        }

        return view('admin.domains.just_missed_them',compact('domains'));
    }

    public function outSourceSold(Request $request)
    {

        $this->validate($request, [
            'domain_name' => 'required|string|max:20',
            'fee' => 'nullable|numeric',
            'price' => 'required|numeric',
            'commission' => 'nullable|numeric',
            'market_place' => 'required|string|max:200',
            'date' => 'required|string',
            'note' => 'nullable|string|max:200',

        ]);
        $markAsSold = new OutSourceSold();
        $markAsSold->name =$request->domain_name;
        $markAsSold->domain_id = base64_decode($request->id);
        $markAsSold->market_place = $request->market_place;
        $markAsSold->fee = $request->fee;
        $markAsSold->price = $request->price;
        $markAsSold->commission = $request->commission;
        $markAsSold->date = $request->date;
        $markAsSold->description = $request->note;
        $markAsSold->save();
        return back()->withMessage('Add Successfully');

    }

    public function outSourceSoldUpdate(Request $request)
    {

        $this->validate($request, [
            'domain_name' => 'required|string|max:20',
            'fee' => 'nullable|numeric',
            'price' => 'required|numeric',
            'commission' => 'nullable|numeric',
            'market_place' => 'required|string|max:200',
            'date' => 'required|string',
            'note' => 'nullable|string|max:200',

        ]);
        $markAsSold = OutSourceSold::find($request->id);
        $markAsSold->name =$request->domain_name;
        $markAsSold->domain_id = base64_decode($request->id);
        $markAsSold->market_place = $request->market_place;
        $markAsSold->fee = $request->fee;
        $markAsSold->price = $request->price;
        $markAsSold->commission = $request->commission;
        $markAsSold->date = $request->date;
        $markAsSold->description = $request->note;
        $markAsSold->save();
        return back()->withMessage('Update Successfully');

    }

    public function outSourceSoldEdit(Request $request)
    {
        $domain = OutSourceSold::find(base64_decode($request->id));
        return view('admin.domains.edit_domain_sold',compact('domain'));
    }


    public function justMissed(Request $request)
    {
        $missed = OutSourceSold::find(base64_decode($request->ddid));
        $missed->just_missed = '1';
        $missed->save();
        return back()->withMessage('Add Successfully');
    }

    public function outSourceSoldDelete(Request $request)
    {
         OutSourceSold::find(base64_decode($request->id))->delete();
        return back()->withMessage('Delete Successfully');
    }

    public function removeJustMissed(Request $request)
    {
        $missed = OutSourceSold::find(base64_decode($request->ddid));
        $missed->just_missed = '0';
        $missed->save();
        return back()->withMessage('Add Successfully');
    }
}
