<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', 'HomeController@index');
Route::get('/contact', 'ContactController@index');
Route::get('/faq', 'FaqController@index');
Route::get('/about', 'AboutController@index');
Route::get('/search', 'SearchController@index');
Route::get('/privacy', 'HomeController@privacy');
Route::get('/domain/profile/{id}/{name}', 'HomeController@domainProfile');
Route::get('/price/plan/{id}', 'PricePlanController@index')->name('priceplane');
Route::get('/escrow', 'HomeController@escrow');
Route::get('/comingsoon', 'HomeController@comingsoon');


Route::get('/user/paymenthistory', 'HomeController@paymenthistory');
Route::get('/user/pdfinvoices', 'HomeController@pdfinvoices');
Route::get('/user/purchaseagreement', 'HomeController@purchaseagreement');
Route::get('/user/thankyou', 'HomeController@thankyou');

Route::get('/cart', 'CartController@index')->name('cart');
Route::get('/cart/remove/{key}', 'CartController@removeCart');
Route::get('/checkout', 'CartController@checkOut')->name('checkout');
Route::post('/payment/done', 'CartController@checkOutDone');


Route::get('/get/states/{id}', 'CartController@getStates');

Route::post('/paypal/pay', 'PayPallController@payWithpaypal');
Route::get('/paypal/done', 'PayPallController@payWithpaypalSuccess');
Route::get('/paypal/cancel', 'PayPallController@payWithpaypalCancel');

Route::get('/admin/login', 'Admin\AuthController@index');


////////////////////////// Subscription ///////////////////////////
Route::get('subscription/checkout', 'SubscriptionController@index')->name('subscriptionCheckout');
Route::post('payment/subscription/done', 'SubscriptionController@payment');
Route::post('payment/subscription/webHook', 'SubscriptionController@webHooks');

Route::post('payment/escrow', 'EscrowController@index')->name('escrow');
Route::get('escrow/after/payment', 'EscrowController@afterPayment');
Route::get('escrow/get/transaction', 'EscrowController@getTransaction');
Route::get('escrow/webhook', 'EscrowController@webHook');

Route::post('contact/save', 'ContactUSController@store');

Route::group([ 'middleware' => 'auth.admin'], function() {
    Route::group(['middleware' => ['role:admin']], function () {
        Route::get('/admin/dashboard', 'Admin\DashboardController@index');
        Route::get('/admin/portfolio', 'Admin\PortfolioController@index');

        ////////////////////////// Domains //////////////////////////

        Route::post('/save/domain', 'Admin\DomainsController@store');
        Route::get('get/domaintab/{id}', 'Admin\DomainsController@getDomainTab');
        Route::get('refresh/data', 'Admin\DomainsController@domainRefresh');
        Route::get('/admin/domain/edit/{id}', 'Admin\DomainsController@edit')->name('edit_domain');
        Route::post('upload/domain', 'Admin\PortfolioController@importExcel');
        Route::get('domain/file/download', 'Admin\PortfolioController@downloadExcel');
        Route::post('update/domain/setting', 'Admin\DomainsController@update');
        Route::post('admin/seo/web', 'Admin\PortfolioController@seoSave');
        Route::post('delete/domain', 'Admin\PortfolioController@delete');
        Route::get('domain/sold', 'Admin\DomainsController@domainSold')->name('soldDomain');
        Route::post('mark/sold/domain', 'Admin\DomainsController@markAsSold');
        Route::get('domain/dropped', 'Admin\DomainsController@dropped')->name('dropped');
        Route::get('domain/under_review', 'Admin\DomainsController@under_review')->name('under_review');
        Route::get('domain/expiring', 'Admin\DomainsController@expiring')->name('expiring');
        Route::get('domain/expired', 'Admin\DomainsController@expired')->name('expired');
        Route::get('domain/cron', 'Admin\DomainsController@croneExpiry');
        Route::get('domain/just_missed_them', 'Admin\OutSourceSoldDomainController@index')->name('just_missed_them');

        ////////////////////////// Plans //////////////////////////

        Route::post('admin/plane/save', 'Admin\PricePlanController@store');
        Route::get('admin/plane/show/{id}', 'Admin\PricePlanController@show');

        ////////////////////////// SEO ///////////////////////////
        Route::get('admin/seo', 'Admin\DomainsController@seo')->name('seo');
        Route::post('admin/seo/save', 'Admin\SEOController@seoSave');
        Route::get('admin/seo/form', 'Admin\SEOController@seoForm');

        ////////////////////////// Inquiries ///////////////////////////
        Route::get('admin/inquiries/general_inquiries', 'Admin\DomainsController@general_inquiries')->name('general_inquiries');
        Route::get('admin/inquiries/general_inquiry_details', 'Admin\DomainsController@general_inquiry_details')->name('general_inquiry_details');

        Route::get('admin/inquiries/customer_inquiries', 'Admin\DomainsController@customer_inquiries')->name('customer_inquiries');
        Route::get('admin/inquiries/customer_inquiry_details', 'Admin\DomainsController@customer_inquiry_details')->name('customer_inquiry_details');

        ////////////////////////// Invoices ///////////////////////////

        Route::get('admin/invoices/invoice_list', 'Admin\DomainsController@invoices')->name('invoice_list');
        Route::get('admin/invoices/invoice_list_details', 'Admin\DomainsController@invoice_list_details')->name('invoice_list_details');

        ////////////////////////// Customers ///////////////////////////

        Route::get('admin/customer/customer_list', 'Admin\DomainsController@customer')->name('customer_list');
        Route::get('admin/customer/customer_details/{id}', 'Admin\DomainsController@customer_details')->name('customer_details');

        ////////////////////////// Payment Details ///////////////////////////
        Route::get('admin/payment_details/incoming_payment', 'Admin\DomainsController@incoming_payment')->name('incoming_payment');
        Route::get('admin/payment_details/received', 'Admin\DomainsController@received')->name('received');
        Route::get('admin/payment_details/onhold_transaction', 'Admin\DomainsController@onhold_transaction')->name('onhold_transaction');
        Route::get('admin/payment_details/paid_transaction', 'Admin\DomainsController@paid_transaction')->name('paid_transaction');

        ////////////////////////// Categories ///////////////////////////
          Route::get('admin/categories/reports', 'Admin\CategoriesController@reports')->name('reports');
        Route::get('admin/categories/list_categories', 'Admin\CategoriesController@index')->name('list_categories');
        Route::post('admin/categories/store', 'Admin\CategoriesController@store');
        Route::post('admin/categories/update', 'Admin\CategoriesController@update');
        Route::get('admin/categories/edit', 'Admin\CategoriesController@edit');

     ///////////////////////////////// Out Source Sold ///////////////////////////////////

        Route::post('domain/outsource/sold', 'Admin\OutSourceSoldDomainController@outSourceSold');
        Route::get('domain/outsource/sold/edit', 'Admin\OutSourceSoldDomainController@outSourceSoldEdit');
        Route::post('domain/outsource/sold/update', 'Admin\OutSourceSoldDomainController@outSourceSoldUpdate');
        Route::post('domain/outsource/sold/delete', 'Admin\OutSourceSoldDomainController@outSourceSoldDelete');
        Route::post('missed/domain', 'Admin\OutSourceSoldDomainController@justMissed');
        Route::post('remove/missed/domain', 'Admin\OutSourceSoldDomainController@removeJustMissed');

        Route::get('evaluation/price/{id}', 'Admin\PortfolioController@getValuePrice');

        ////////////////////////// Google Analytics ///////////////////////////

        Route::get('admin/google_analytics/google_analytics', 'Admin\DomainsController@google_analytics')->name('google_analytics');
        Route::get('admin/analytics', 'Admin\AnalysisController@index');


    });
});

Auth::routes();

Route::get('/home', 'HomeController@index')->name('home');

Route::post('/user/login', 'Users\LoginController@login');

Route::group([ 'middleware' => 'auth'], function() {

    Route::get('/user/dashboard', 'HomeController@dashboard');

    Route::get('/user/billinginformation', 'HomeController@billinginformation');

    Route::post('/update/address', 'HomeController@updateAddress');
});
